FileEntity class

Constructors

FileEntity({XFile? pickedFile, Uint8List? bytes, String? path, String? fileName, String? mimeType = 'Images', String? uploadingToastTxt, Map<String, dynamic>? queryParams, String? imgFieldName, String? urlFieldName, String? accessToken})
const

Properties

accessToken String?
final
bytes Uint8List?
final
fileName String?
final
hashCode int
The hash code for this object.
no setterinherited
imgFieldName String?
final
mimeType String?
final
path String?
final
pickedFile XFile?
final
props List<Object?>
The list of properties that will be used to determine whether two instances are equal.
no setter
queryParams Map<String, dynamic>?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stringify bool?
If set to true, the toString method will be overridden to output this instance's props.
no setterinherited
uploadingToastTxt String?
final
urlFieldName String?
final

Methods

copyWith({XFile? pickedFile, Uint8List? bytes, String? path, String? fileName, String? mimeType, String? uploadingToastTxt, Map<String, dynamic>? queryParams, String? imgFieldName, String? urlFieldName, String? accessToken}) FileEntity
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited